Module data
mbon
0.2.0
Module data
Module Items
Modules
Enums
In crate mbon
mbon
Module
data
Internal data structs
Here, you’ll find
Value
,
Mark
, and
Type
.
Modules

de
Serde Deserializer implementation for
Value
ser
Serde Serializer implementation for
Value
Enums

Mark
An indicator of what’s contained in the value.
Type
An indicator for what type of value is stored
Value
The basic unit for data in binary save data.